==> zio-aws-elasticsearch_2.12-7.21.15.5-sources.jar: zio/aws/elasticsearch/model/EncryptionAtRestOptions.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.KmsKeyId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EncryptionAtRestOptions(
    enabled: Optional[Boolean] = Optional.Absent,
    kmsKeyId: Optional[KmsKeyId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions = {
    import EncryptionAtRestOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.EncryptionAtRestOptions.ReadOnly =
    zio.aws.elasticsearch.model.EncryptionAtRestOptions.wrap(buildAwsValue())
}
object EncryptionAtRestOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.EncryptionAtRestOptions =
      zio.aws.elasticsearch.model.EncryptionAtRestOptions(
        enabled.map(value => value),
        kmsKeyId.map(value => value)
      )
    def enabled: Optional[Boolean]
    def kmsKeyId: Optional[KmsKeyId]
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
  ) extends zio.aws.elasticsearch.model.EncryptionAtRestOptions.ReadOnly {
    override val enabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: Boolean)
    override val kmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKeyId())
      .map(value => zio.aws.elasticsearch.model.primitives.KmsKeyId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
  ): zio.aws.elasticsearch.model.EncryptionAtRestOptions.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-elasticsearch_2.13-5.17.128.1-sources.jar: zio/aws/elasticsearch/model/EncryptionAtRestOptions.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.KmsKeyId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class EncryptionAtRestOptions(
    enabled: Option[Boolean] = None,
    kmsKeyId: Option[KmsKeyId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions = {
    import EncryptionAtRestOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.EncryptionAtRestOptions.ReadOnly =
    zio.aws.elasticsearch.model.EncryptionAtRestOptions.wrap(buildAwsValue())
}
object EncryptionAtRestOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.EncryptionAtRestOptions =
      zio.aws.elasticsearch.model.EncryptionAtRestOptions(
        enabled.map(value => value),
        kmsKeyId.map(value => value)
      )
    def enabled: Option[Boolean]
    def kmsKeyId: Option[KmsKeyId]
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
  ) extends zio.aws.elasticsearch.model.EncryptionAtRestOptions.ReadOnly {
    override val enabled: Option[Boolean] =
      scala.Option(impl.enabled()).map(value => value: Boolean)
    override val kmsKeyId: Option[KmsKeyId] = scala
      .Option(impl.kmsKeyId())
      .map(value => zio.aws.elasticsearch.model.primitives.KmsKeyId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.EncryptionAtRestOptions
  ): zio.aws.elasticsearch.model.EncryptionAtRestOptions.ReadOnly = new Wrapper(
    impl
  )
}
